application:setBackgroundColor(0x306090)


-- set direct from table
function testbatch1()

	local function add(t, ...)
		local n = select("#", ...)	
		for i=1,n do
			t[#t+1] = select(i, ...)
		end
	end
	 

	 
	local vertices = {}
	local indices = {}
	local velocities = {}
	 
	local nrect = 0
	 
	for i = -400, 400, 5 do
		for j = -400, 400, 5 do
			local x = i / 275
			local y = -j / 275
	 
			-- implicit heart function is from http://mathworld.wolfram.com/HeartCurve.html
			local a = x * x + y * y - 1
			local f = a * a * a - x * x * y * y * y
	 
			if f < 0 then
				local n = #vertices/2
	 
				-- add 4 corners
				add(vertices, i,     j)
				add(vertices, i + 4, j)
				add(vertices, i + 4, j + 4)
				add(vertices, i,     j + 4)
	 
				-- add 2 triangles to indices
				add(indices, n + 1, n + 2, n + 3)
				add(indices, n + 1, n + 3, n + 4)
	 
				-- and velocities
				add(velocities, x + math.random(-100,100)/200, -y + math.random(-100,100)/200)
	 
				nrect = nrect + 1
			end
		end
	end
	 
	print("# of rects = "..nrect)
	 
	local mesh = Mesh.new()
	 
	mesh:setVertexArray(vertices)
	mesh:setIndexArray(indices)
	mesh:setPosition(768/2, 1024/2)
	 
	stage:addChild(mesh)
	 
	local function onEnterFrame()
		
		for i = 1,#vertices,8 do
			local ind = (i - 1) / 4 + 1
			local vx = velocities[ind]
			local vy = velocities[ind+1]
	 
			vertices[i+0] = vertices[i+0] + vx
			vertices[i+1] = vertices[i+1] + vy
			vertices[i+2] = vertices[i+2] + vx
			vertices[i+3] = vertices[i+3] + vy
			vertices[i+4] = vertices[i+4] + vx
			vertices[i+5] = vertices[i+5] + vy
			vertices[i+6] = vertices[i+6] + vx
			vertices[i+7] = vertices[i+7] + vy
		end
		
		mesh:setVertexArray(vertices)	
	end
	 
	--stage:addEventListener(Event.ENTER_FRAME, onEnterFrame)
end
-------- object model
function testbatch2()
	local batch = Batch.new()
	local nrect = 0
	for i = -400, 400, 5 do
		for j = -400, 400, 5 do
			local x = i / 275
			local y = -j / 275	 
			--
			local a = x * x + y * y - 1
			local f = a * a * a - x * x * y * y * y
			local r
			
			if f < 0 then
				r = Rect.new(i, j, 4, 4) 				
				r:setVel(x + math.random(-100,100)/200, -y + math.random(-100,100)/200)
				--
				batch:addSprite(r)
				--
				nrect = nrect + 1
			end
		end
	end
	
	print("# of rects = "..nrect)
	
	batch:setPosition(768/2, 1024/2)
 
	stage:addChild(batch)
	 
	local function onEnterFrame()
		for i=1, #batch.children, 1 do
			batch.children[i]:update()
		end
		batch:render()
	end
	 
	stage:addEventListener(Event.ENTER_FRAME, onEnterFrame)
end

--
testbatch1()
--testbatch2()


------------
--SHOW FPS--
------------

local frame = 0
local timer = os.timer()
local text = TextField.new(nil, "fps:")
text:setPosition(10,60)
text:setScale(2)
stage:addChild(text)
local function displayFps()
	frame = frame + 1
	if frame == 60 then
		local currentTimer = os.timer()
		text:setText("fps: "..(60 / (currentTimer - timer)))
		frame = 0
		timer = currentTimer	
	end
end
 
stage:addEventListener(Event.ENTER_FRAME, displayFps)